import { DevServerContext, type Logger, type ServerConfig } from '../types/index.js';
import { AuthenticatedWebSocketServer } from './connection/web-socket-server.js';
import { Client } from './connection/client.js';
/**
 * This class represents the central place where the LWC dev server coordination occurs.
 *
 * ModuleGraph -> Is responsible for discovering modules and tracking changes to them
 * Connection -> An authenticated connection between hmr-client and dev server
 * Client -> A stateful object that tracks a hmr-client connected to the dev server
 *
 * This class also manages resources that will need clean up, like the file watcher, WebSockets.
 */
export declare class LWCServer {
    clients: Set<Client>;
    wss: AuthenticatedWebSocketServer;
    context: DevServerContext;
    identityToken?: string;
    constructor(config: ServerConfig, wss: AuthenticatedWebSocketServer, logger: Logger);
    stopServer(): void;
    moduleUpdateHandler: (modulePath: string) => void;
}
/**
 * Initialize an LWC Dev Server with the specified server configuration.
 * @returns Returns an initialized LWC dev server.
 */
export declare function startLwcDevServer(config: ServerConfig): Promise<LWCServer>;
